==> dokuwiki-2020.07.29.tgz: dokuwiki/lib/plugins/extension/lang/vi/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Thien Hau <thienhau.9a14@gmail.com>
 */
$lang['menu']                  = 'Quản lý phần mở rộng';
$lang['tab_plugins']           = 'Plugin đã cài đặt';
$lang['tab_templates']         = 'Chủ đề đã cài đặt';
$lang['tab_search']            = 'Tìm kiếm và Cài đặt';
$lang['tab_install']           = 'Cài đặt thủ công';
$lang['notimplemented']        = 'Tính năng này chưa được triển khai';
$lang['notinstalled']          = 'Phần mở rộng này chưa được cài đặt';
$lang['alreadyenabled']        = 'Phần mở rộng này đã được kích hoạt';
$lang['alreadydisabled']       = 'Phần mở rộng này đã bị vô hiệu hóa';
$lang['pluginlistsaveerror']   = 'Có lỗi khi lưu danh sách plugin';
$lang['unknownauthor']         = 'Không rõ tác giả';
$lang['unknownversion']        = 'Không rõ phiên bản';
$lang['btn_info']              = 'Hiện thêm thông tin';
$lang['btn_update']            = 'Cập nhật';
$lang['btn_uninstall']         = 'Gỡ bỏ';
$lang['btn_enable']            = 'Kích hoạt';
$lang['btn_disable']           = 'Vô hiệu hóa';
$lang['btn_install']           = 'Cài đặt';
$lang['btn_reinstall']         = 'Cài đặt lại';
$lang['js']['reallydel']       = 'Thực sự muốn gỡ cài đặt phần mở rộng này?';
$lang['js']['display_viewoptions'] = 'Tùy chọn xem:';
$lang['js']['display_enabled'] = 'đã kích hoạt';
$lang['js']['display_disabled'] = 'đã vô hiệu hóa';
$lang['js']['display_updatable'] = 'có sẫn cập nhật';
$lang['search_for']            = 'Tìm kiếm phần mở rộng:';
$lang['search']                = 'Tìm kiếm';
$lang['extensionby']           = '<strong>%s</strong> bởi %s';
$lang['screenshot']            = 'Ảnh chụp màn hình của %s';
$lang['popularity']            = 'Độ phổ biến: %s%%';
$lang['homepage_link']         = 'Tài liệu';
$lang['bugs_features']         = 'Lỗi';
$lang['tags']                  = 'Thẻ';
$lang['author_hint']           = 'Tìm kiếm phần mở rộng của tác giả này';
$lang['installed']             = 'Đã cài đặt:';
$lang['downloadurl']           = 'URL tải về:';
$lang['repository']            = 'Repository:';
$lang['unknown']               = '<em>không rõ</em>';
$lang['installed_version']     = 'Phiên bản đã cài đặt:';
$lang['install_date']          = 'Cập nhật cuối cùng của bạn:';
$lang['available_version']     = 'Có sẵn phiên bản:';
$lang['compatible']            = 'Tương thích với:';
$lang['depends']               = 'Phụ thuộc vào:';
$lang['similar']               = 'Tương tự như:';
$lang['conflicts']             = 'Xung đột với:';
$lang['donate']                = 'Thích thứ này?';
$lang['donate_action']         = 'Mua cho tác giả một ly cà phê!';
$lang['repo_retry']            = 'Thử lại';
$lang['provides']              = 'Cung cấp:';
$lang['status']                = 'Trạng thái:';
$lang['status_installed']      = 'đã cài đặt';
$lang['status_not_installed']  = 'chưa cài đặt';
$lang['status_protected']      = 'đã bảo vệ';
$lang['status_enabled']        = 'đã kích hoạt';
$lang['status_disabled']       = 'đã vô hiệu hóa';
$lang['status_unmodifiable']   = 'không thể thay đổi';
$lang['status_plugin']         = 'plugin';
$lang['status_template']       = 'chủ đề';
$lang['status_bundled']        = 'đi kèm';
$lang['msg_enabled']           = 'Đã kích hoạt plugin %s';
$lang['msg_disabled']          = 'Đã vô hiệu hóa plugin %s';
$lang['msg_delete_success']    = 'Đã gỡ cài đặt phần mở rộng %s';
$lang['msg_delete_failed']     = 'Thất bại khi gỡ cài đặt phần mở rộng %s';
$lang['msg_template_install_success'] = 'Cài đặt thành công chủ đề %s';
$lang['msg_template_update_success'] = 'Cập nhật thành công chủ đề %s';
$lang['msg_plugin_install_success'] = 'Cài đặt thành công plugin %s';
$lang['msg_plugin_update_success'] = 'Cập nhật thành công plugin %s';
$lang['msg_upload_failed']     = 'Tải tập tin không thành công';
$lang['msg_nooverwrite']       = 'Phần mở rộng %s đã tồn tại để không bị ghi đè; để ghi đè, đánh dấu tùy chọn ghi đè';
$lang['missing_dependency']    = '<strong>Thiếu hoặc đã vô hiệu phần hóa phụ thuộc:</strong> %s';
$lang['security_issue']        = '<strong>Vấn đề bảo mật:</strong> %s';
$lang['security_warning']      = '<strong>Cảnh báo bảo mật:</strong> %s';
$lang['update_available']      = '<strong>Cập nhật:</strong> Phiên bản mới %s hiện có sẵn.';
$lang['wrong_folder']          = '<strong>Plugin đã được cài đặt không đúng:</strong> Đổi tên đường dẫn plugin "%s" thành "%s".';
$lang['url_change']            = '<strong>URL thay đổi:</strong>URL tải xuống đã thay đổi kể từ lần tải xuống trước. Kiểm tra xem URL mới có hợp lệ không trước khi cập nhật phần mở rộng.<br/>Mới: %s<br/>Cũ: %s';
$lang['error_badurl']          = 'URL phải bắt đầu bằng http hoặc https';
$lang['error_dircreate']       = 'Không thể tạo thư mục tạm thời để nhận tải xuống';
$lang['error_download']        = 'Không thể tải xuống tập tin: %s';
$lang['error_decompress']      = 'Không thể giải nén tập tin đã tải xuống. Việc này có thể là kết quả của một tải xuống xấu, trường hợp này bạn nên thử lại; hoặc nếu định dạng nén có thể không xác định, bạn sẽ cần phải tải xuống và cài đặt thủ công.';
$lang['error_findfolder']      = 'Không thể xác định đường dẫn phần mở rộng, bạn cần tải xuống và cài đặt thủ công';
$lang['error_copy']            = 'Có lỗi sao chép tập tin trong khi cố gắng cài đặt tập tin cho đường dẫn <em>%s</em>: đĩa có thể đầy hoặc quyền truy cập tập tin có thể không chính xác. Việc này có thể đã dẫn đến plugin được cài đặt một phần và khiến cài đặt wiki của bạn không ổn định';
$lang['noperms']               = 'Không thể ghi đường dẫn phần mở rộng';
$lang['notplperms']            = 'Không thể ghi đường dẫn Chủ đề';
$lang['nopluginperms']         = 'Không thể ghi đường dẫn Plugin';
$lang['git']                   = 'Phần mở rộng này đã được cài đặt qua git, bạn có thể không muốn cập nhật nó ở đây.';
$lang['auth']                  = 'Plugin xác thực này không được kích hoạt trong cấu hình, hãy xem xét đến việc vô hiệu hóa nó.';
$lang['install_url']           = 'Cài đặt từ URL:';
$lang['install_upload']        = 'Tải lên phần mở rộng:';
$lang['repo_error']            = 'Không thể kết nối đến Kho lưu trữ plugin. Đảm bảo rằng máy chủ của bạn được phép kết nối với www.dokuwiki.org và kiểm tra cài đặt proxy của bạn.';
$lang['nossl']                 = 'PHP của bạn dường như bỏ lỡ hỗ trợ SSL. Tải xuống sẽ không hoạt động đối với nhiều phần mở rộng DokuWiki.';

==> dokuwiki-2024.02.06.tgz: dokuwiki/lib/plugins/extension/lang/vi/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Thien Hau <thienhau.9a14@gmail.com>
 */
$lang['menu']                  = 'Quản lý phần mở rộng';
$lang['tab_plugins']           = 'Plugin đã cài đặt';
$lang['tab_templates']         = 'Chủ đề đã cài đặt';
$lang['tab_search']            = 'Tìm kiếm và Cài đặt';
$lang['tab_install']           = 'Cài đặt thủ công';
$lang['notimplemented']        = 'Tính năng này chưa được triển khai';
$lang['notinstalled']          = 'Phần mở rộng này chưa được cài đặt';
$lang['alreadyenabled']        = 'Phần mở rộng này đã được kích hoạt';
$lang['alreadydisabled']       = 'Phần mở rộng này đã bị vô hiệu hóa';
$lang['pluginlistsaveerror']   = 'Có lỗi khi lưu danh sách plugin';
$lang['unknownauthor']         = 'Không rõ tác giả';
$lang['unknownversion']        = 'Không rõ phiên bản';
$lang['btn_info']              = 'Hiện thêm thông tin';
$lang['btn_update']            = 'Cập nhật';
$lang['btn_uninstall']         = 'Gỡ bỏ';
$lang['btn_enable']            = 'Kích hoạt';
$lang['btn_disable']           = 'Vô hiệu hóa';
$lang['btn_install']           = 'Cài đặt';
$lang['btn_reinstall']         = 'Cài đặt lại';
$lang['js']['reallydel']       = 'Thực sự muốn gỡ cài đặt phần mở rộng này?';
$lang['js']['display_viewoptions'] = 'Tùy chọn xem:';
$lang['js']['display_enabled'] = 'đã kích hoạt';
$lang['js']['display_disabled'] = 'đã vô hiệu hóa';
$lang['js']['display_updatable'] = 'có sẫn cập nhật';
$lang['search_for']            = 'Tìm kiếm phần mở rộng:';
$lang['search']                = 'Tìm kiếm';
$lang['extensionby']           = '<strong>%s</strong> bởi %s';
$lang['screenshot']            = 'Ảnh chụp màn hình của %s';
$lang['popularity']            = 'Độ phổ biến: %s%%';
$lang['homepage_link']         = 'Tài liệu';
$lang['bugs_features']         = 'Lỗi';
$lang['tags']                  = 'Thẻ';
$lang['author_hint']           = 'Tìm kiếm phần mở rộng của tác giả này';
$lang['installed']             = 'Đã cài đặt:';
$lang['downloadurl']           = 'URL tải về:';
$lang['repository']            = 'Repository:';
$lang['unknown']               = '<em>không rõ</em>';
$lang['installed_version']     = 'Phiên bản đã cài đặt:';
$lang['install_date']          = 'Cập nhật cuối cùng của bạn:';
$lang['available_version']     = 'Có sẵn phiên bản:';
$lang['compatible']            = 'Tương thích với:';
$lang['depends']               = 'Phụ thuộc vào:';
$lang['similar']               = 'Tương tự như:';
$lang['conflicts']             = 'Xung đột với:';
$lang['donate']                = 'Thích thứ này?';
$lang['donate_action']         = 'Mua cho tác giả một ly cà phê!';
$lang['repo_retry']            = 'Thử lại';
$lang['provides']              = 'Cung cấp:';
$lang['status']                = 'Trạng thái:';
$lang['status_installed']      = 'đã cài đặt';
$lang['status_not_installed']  = 'chưa cài đặt';
$lang['status_protected']      = 'đã bảo vệ';
$lang['status_enabled']        = 'đã kích hoạt';
$lang['status_disabled']       = 'đã vô hiệu hóa';
$lang['status_unmodifiable']   = 'không thể thay đổi';
$lang['status_plugin']         = 'plugin';
$lang['status_template']       = 'chủ đề';
$lang['status_bundled']        = 'đi kèm';
$lang['msg_enabled']           = 'Đã kích hoạt plugin %s';
$lang['msg_disabled']          = 'Đã vô hiệu hóa plugin %s';
$lang['msg_delete_success']    = 'Đã gỡ cài đặt phần mở rộng %s';
$lang['msg_delete_failed']     = 'Thất bại khi gỡ cài đặt phần mở rộng %s';
$lang['msg_template_install_success'] = 'Cài đặt thành công chủ đề %s';
$lang['msg_template_update_success'] = 'Cập nhật thành công chủ đề %s';
$lang['msg_plugin_install_success'] = 'Cài đặt thành công plugin %s';
$lang['msg_plugin_update_success'] = 'Cập nhật thành công plugin %s';
$lang['msg_upload_failed']     = 'Tải tập tin không thành công';
$lang['msg_nooverwrite']       = 'Phần mở rộng %s đã tồn tại để không bị ghi đè; để ghi đè, đánh dấu tùy chọn ghi đè';
$lang['missing_dependency']    = '<strong>Thiếu hoặc đã vô hiệu hóa phần phụ thuộc:</strong> %s';
$lang['security_issue']        = '<strong>Vấn đề bảo mật:</strong> %s';
$lang['security_warning']      = '<strong>Cảnh báo bảo mật:</strong> %s';
$lang['update_available']      = '<strong>Cập nhật:</strong> Phiên bản mới %s hiện có sẵn.';
$lang['wrong_folder']          = '<strong>Plugin đã được cài đặt không đúng:</strong> Đổi tên đường dẫn plugin "%s" thành "%s".';
$lang['url_change']            = '<strong>URL thay đổi:</strong>URL tải xuống đã thay đổi kể từ lần tải xuống trước. Kiểm tra xem URL mới có hợp lệ không trước khi cập nhật phần mở rộng.<br/>Mới: %s<br/>Cũ: %s';
$lang['error_badurl']          = 'URL phải bắt đầu bằng http hoặc https';
$lang['error_dircreate']       = 'Không thể tạo thư mục tạm thời để nhận tải xuống';
$lang['error_download']        = 'Không thể tải xuống tập tin: %s';
$lang['error_decompress']      = 'Không thể giải nén tập tin đã tải xuống. Việc này có thể là kết quả của một tải xuống xấu, trường hợp này bạn nên thử lại; hoặc nếu định dạng nén có thể không xác định, bạn sẽ cần phải tải xuống và cài đặt thủ công.';
$lang['error_findfolder']      = 'Không thể xác định đường dẫn phần mở rộng, bạn cần tải xuống và cài đặt thủ công';
$lang['error_copy']            = 'Có lỗi sao chép tập tin trong khi cố gắng cài đặt tập tin cho đường dẫn <em>%s</em>: đĩa có thể đầy hoặc quyền truy cập tập tin có thể không chính xác. Việc này có thể đã dẫn đến plugin được cài đặt một phần và khiến cài đặt wiki của bạn không ổn định';
$lang['noperms']               = 'Không thể ghi đường dẫn phần mở rộng';
$lang['notplperms']            = 'Không thể ghi đường dẫn Chủ đề';
$lang['nopluginperms']         = 'Không thể ghi đường dẫn Plugin';
$lang['git']                   = 'Phần mở rộng này đã được cài đặt qua git, bạn có thể không muốn cập nhật nó ở đây.';
$lang['auth']                  = 'Plugin xác thực này không được kích hoạt trong cấu hình, hãy xem xét đến việc vô hiệu hóa nó.';
$lang['install_url']           = 'Cài đặt từ URL:';
$lang['install_upload']        = 'Tải lên phần mở rộng:';
$lang['repo_error']            = 'Không thể kết nối đến Kho lưu trữ plugin. Đảm bảo rằng máy chủ của bạn được phép kết nối với www.dokuwiki.org và kiểm tra cài đặt proxy của bạn.';
$lang['nossl']                 = 'PHP của bạn dường như bỏ lỡ hỗ trợ SSL. Tải xuống sẽ không hoạt động đối với nhiều phần mở rộng DokuWiki.';
